const path       = require('path')
const express    = require('express')
const bodyParser = require('body-parser')
const colors     = require('colors')
const _config    = require(`./model/config`)

const app = express()

module.exports = class CreateStdREST {
  constructor(params) {
    this.pages    = params.pages
    this.static   = params.static
    this.HOST     = params.host || '0.0.0.0'
    this.PORT     = params.port || 8880
    this.module   = params.module || Object.keys(_config)
    this.BD       = params.bd || 'mongo'
    this.protocol = params.protocol || 'http'

    app.use(express.static(path.resolve(process.cwd(), this.static)))
    app.use(bodyParser.urlencoded({ extended: true }))
    app.use(bodyParser.json())

    this.pages.forEach(page => {
      app.get(`/${page}`, (req, res) => {
        res.sendfile(path.resolve(process.cwd(), `${this.static}/${page}.html`))
      })
    })

    this.module.forEach(module => {
      const _mod    = require(`./controllers/${module}/router`)

      this[`${module}Data`] = function(params) {
          _config[module] = params
      }

      app.use(`/${module}`, _mod)
    })
  }

  serverStart() {
    try {
      app.listen(this.PORT, this.HOST, (err) => {
        if (err) {
          throw new Error(err)
        }

        console.log('')

        if (process.env.NODE_ENV) {
          console.log(colors.yellow('ENV is'), colors.red(process.env.NODE_ENV.toUpperCase()))
        }
        
        console.log(colors.red('Server start from'), colors.cyan.bold(`http://${this.HOST}:${this.PORT}`))
        console.log('')
        console.log(colors.blue('Api listening started...'))
      })
    } catch (err) {
      console.error(colors.red.bold(err.message))
      process.exit(1)
    }
  }
}